@@ -3,7 +3,7 @@ package My::Module::Test;
 use strict;
 use warnings;
 
-use base qw{ Exporter };
+use Exporter qw{ import };
 
 use PPIx::Regexp;
 use PPIx::Regexp::Dumper;
@@ -13,7 +13,7 @@ use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number refaddr };
 use Test::More 0.88;
 
-our $VERSION = '0.047';
+our $VERSION = '0.055';
 
 our @EXPORT_OK = qw{
     cache_count
@@ -56,7 +56,7 @@ my (
     $obj,		# Current object:
     			#    PPIx::Regexp::Tokenizer if set by tokenize(),
 			#    PPIx::Regexp if set by parse(), or
-			#    PPIx::Regexp::Element is set by navigate().
+			#    PPIx::Regexp::Element if set by navigate().
     $parse,		# Result of parse:
     			#    array ref if set by tokenize(), or
 			#    PPIx::Regexp object if set by parse()
@@ -69,7 +69,7 @@ sub cache_count {		## no critic (RequireArgUnpacking)
     $obj = undef;
     $parse = undef;
     _pause();
-    $result = PPIx::Regexp->_cache_size();
+    $result = PPIx::Regexp->__cache_size();
     @_ = ( $result, $expect,
 	"Should be $expect leftover cache contents" );
     goto &is;
@@ -201,7 +201,7 @@ sub false {		## no critic (RequireArgUnpacking)
 sub finis {		## no critic (RequireArgUnpacking)
     $obj = $parse = $result = undef;
     _pause();
-    $result = PPIx::Regexp::Element->_parent_keys();
+    $result = PPIx::Regexp::Element->__parent_keys();
     @_ = ( $result, 0, 'Should be no leftover objects' );
     goto &is;
 }
@@ -666,7 +666,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
