@@ -55,6 +55,14 @@ for little tangible gain.
 
 =head1 NOTICE
 
+The use of this class to parse non-regexp quote-like strings was an
+experiment that I consider failed. Therefore this use is
+B<deprecated> in favor of L<PPIx::QuoteLike|PPIx::QuoteLike>. Six months
+after the release of version 0.053, the first use of the C<parse>
+argument to L<new()|/new> will result in a warning. Six months after
+that, all uses of the C<parse> argument will result in a warning. After
+another six months, the C<parse> argument will become fatal.
+
 The author will attempt to preserve the documented interface, but if the
 interface needs to change to correct some egregiously bad design or
 implementation decision, then it will change.  Any incompatible changes
@@ -106,6 +114,26 @@ character class, per C<perl5234delta>. Formerly any white space
 character parsed as whitespace. This change in C<PPIx::Regexp> will be
 reverted if the change in Perl does not make it into Perl 5.24.0.
 
+=item Unescaped literal left curly brackets
+
+These are being removed in positions where quantifiers are legal, so
+that they can be used for new functionality. Some of them are gone in
+5.25.1, others will be removed in a future version of Perl. In
+situations where they have been removed,
+L<perl_version_removed()|/perl_version_removed> will return the version
+in which they were removed. When the new functionality appears, the
+parse produced by this software will reflect the new functionality.
+
+B<NOTE> that a literal left curly after a literal character was made an
+error in Perl 5.25.1, but became a warning again in 5.27.1 due to its
+use in GNU Autoconf.  Whether it will ever become illegal again is not
+clear to me based on the contents of F<perl5271delta>. At the moment
+C<PPIx::Regexp> considers this usage to have been removed in 5.25.1, and
+this will not change based on anything in 5.27.x. But if 5.26.1 comes
+out allowing this usage, the removal version will become C<undef>. The
+same will apply to any other usages that were re-allowed in 5.27.1, if I
+can identify them.
+
 =back
 
 There are very probably other examples of this. When they come to light
@@ -113,13 +141,11 @@ they will be documented as producing the modern parse, and the code
 modified to produce this parse if necessary.
 
 The functionality that parses string literals (the C<parse> argument to
-C<new()>) was introduced in version 0.045, and should be considered
-experimental. It is a bit of a kluge in any case, especially in the
-appropriateness of class names to this use. But the actual parsing of a
-Perl string literal is not too different than the parsing of an C<s///>
-replacement string, so I thought that if someone wanted a string literal
-parse badly enough to deal with the kluginess I could provide it fairly
-easily.
+C<new()>) was introduced in version 0.045, but its use is discouraged.
+The preferred package for string literals is
+L<PPIx::QuoteLike|PPIx::QuoteLike>, and once I consider that package to
+be stable the string literal functionality in this package will be put
+through a deprecation cycle and removed.
 
 =head1 METHODS
 
@@ -143,7 +169,7 @@ use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.050';
+our $VERSION = '0.055';
 
 =head2 new
 
@@ -205,6 +231,11 @@ This option specifies what kind of parse is to be done. Possible values
 are C<'regex'>, C<'string'>, or C<'guess'>. Any value but C<'regex'> is
 experimental.
 
+As it turns out, I consider parsing non-regexp quote-like things with
+this class to be a failed experiment, and the relevant functionality is
+being deprecated and removed in favor of
+L<PPIx::QuoteLike|PPIx::QuoteLike>. See above for details.
+
 If C<'regex'> is specified, the first argument is expected to be a valid
 regex, and parsed as though it were.
 
@@ -727,6 +758,36 @@ to that version of Perl, it was simply parsed as C<v>. So
 prints "yes" under Perl 5.8.9, but "no" under 5.10.0. C<PPIx::Regexp>
 generally assumes the more modern parse in cases like this.
 
+=head2 Equivocation
+
+Very occasionally, a construction will be removed and then added back --
+and then, conceivably, removed again. In this case, the plan is for
+L<perl_version_introduced()|PPIx::Regexp/perl_version_introduced> to
+return the earliest version in which the construction appeared, and
+L<perl_version_removed()> to return the version after the last version
+in which it appeared (whether production or development), or C<undef> if
+it is in the highest-numbered Perl.
+
+The constructions involved in this are:
+
+=head3 Un-escaped literal left curly after literal
+
+That is, something like C<< qr<x{> >>.
+
+This was made an error in C<5.25.1>, and it was an error in C<5.26.0>.
+But it became a warning again in C<5.27.1>. The F<perl5271delta> says it
+was re-instated because the changes broke GNU Autoconf, and the warning
+message says it will be removed in Perl C<5.30>.
+
+Accordingly,
+L<perl_version_introduced()|PPIx::Regexp/perl_version_introduced>
+returns C<5.0>. At the moment
+L<perl_version_removed()|PPIx::Regexp/perl_version_removed> returns
+C<'5.025001'>, but if this construction warns in Perl C<5.26.1> this
+will become C<undef>. This is not quite the same as described above, but
+is consistent with the L<NOTICE|/NOTICE> near the beginning of this
+document.
+
 =head2 Static Parsing
 
 It is well known that Perl can not be statically parsed. That is, you
@@ -808,7 +869,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
