@@ -3,7 +3,7 @@ package PPIx::Regexp::Constant;
 use strict;
 use warnings;
 
-our $VERSION = '0.047';
+our $VERSION = '0.055';
 
 use base qw{ Exporter };
 
@@ -12,12 +12,19 @@ our @EXPORT_OK = qw{
     COOKIE_QUANT
     COOKIE_QUOTE
     COOKIE_REGEX_SET
+    FALSE
+    LITERAL_LEFT_CURLY_ALLOWED
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_1
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_2
     MINIMUM_PERL
     MODIFIER_GROUP_MATCH_SEMANTICS
+    MSG_PROHIBITED_BY_STRICT
+    NODE_UNKNOWN
     RE_CAPTURE_NAME
     STRUCTURE_UNKNOWN
     TOKEN_LITERAL
     TOKEN_UNKNOWN
+    TRUE
 };
 
 use constant COOKIE_CLASS	=> ']';
@@ -25,10 +32,22 @@ use constant COOKIE_QUANT	=> '}';
 use constant COOKIE_QUOTE	=> '\\E';
 use constant COOKIE_REGEX_SET	=> '])';
 
+use constant FALSE		=> 0;
+use constant TRUE		=> 1;
+
+use constant LITERAL_LEFT_CURLY_ALLOWED		=> undef;
+use constant LITERAL_LEFT_CURLY_REMOVED_PHASE_1	=> '5.025001';
+use constant LITERAL_LEFT_CURLY_REMOVED_PHASE_2	=> undef;
+
 use constant MINIMUM_PERL	=> '5.000';
 
 use constant MODIFIER_GROUP_MATCH_SEMANTICS => 'match_semantics';
 
+use constant MSG_PROHIBITED_BY_STRICT	=>
+    q<prohibited by "use re 'strict'">;
+
+use constant NODE_UNKNOWN	=> 'PPIx::Regexp::Node::Unknown';
+
 # The perlre for Perl 5.010 says:
 #
 #      Currently NAME is restricted to simple identifiers only.  In
@@ -107,6 +126,25 @@ C<\Q> is encountered, and it persists until the next C<\E>.
 
 The name of the cookie used to control regular expression sets.
 
+=head2 LITERAL_LEFT_CURLY_ALLOWED
+
+The Perl version at which allowed unescaped literal left curly brackets
+were removed. This may make more sense if I mention that its value is
+C<undef>.
+
+=head2 LITERAL_LEFT_CURLY_REMOVED_PHASE_1
+
+The Perl version at which the first phase of unescaped literal left
+curly bracket removal took place. The value of this constant is
+C<'5.025001'>.
+
+=head2 LITERAL_LEFT_CURLY_REMOVED_PHASE_2
+
+The Perl version at which the second phase of unescaped literal left
+curly bracket removal took place. The value of this constant is
+C<undef>, but it will be assigned a value when the timing of the second
+phase is known.
+
 =head2 MINIMUM_PERL
 
 The minimum version of Perl understood by this parser, as a float. It is
@@ -119,6 +157,17 @@ The name of the
 L<PPIx::Regexp::Token::Modifier|PPIx::Regexp::Token::Modifier> group
 used to control match semantics.
 
+=head2 MSG_PROHIBITED_BY_STRICT
+
+An appropriate error message for an unknown entity created because
+C<'strict'> was in effect. This is rank ad-hocery, and more than usually
+subject to being changed, without any notice whatsoever. Caveat user.
+
+=head2 NODE_UNKNOWN
+
+The name of the class that represents an unknown node. That is,
+L<PPIx::Regexp::Node::Unknown|PPIx::Regexp::Node::Unknown>.
+
 =head2 RE_CAPTURE_NAME
 
 A string representation of a regular expression that matches the name of
@@ -126,7 +175,7 @@ a named capture buffer.
 
 =head2 STRUCTURE_UNKNOWN
 
-The name of the class that represents the unknown structure. That is,
+The name of the class that represents an unknown structure. That is,
 L<PPIx::Regexp::Structure::Unknown|PPIx::Regexp::Structure::Unknown>.
 
 =head2 TOKEN_LITERAL
@@ -150,7 +199,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
