@@ -44,7 +44,7 @@ use PPIx::Regexp;
 use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 
-our $VERSION = '0.047';
+our $VERSION = '0.055';
 
 =head2 new
 
@@ -113,6 +113,18 @@ displayed.
 If true, postfix dereferences are recognized in code and interpolations.
 See the tokenizer's L<new()|PPIx::Regexp::Tokenizer/new> for details.
 
+=item strict boolean
+
+This option is passed on to the parser, where it specifies whether the
+parse should assume C<use re 'strict'> is in effect.
+
+The C<'strict'> pragma was introduced in Perl 5.22, and its
+documentation says that it is experimental, and that there is no
+commitment to backward compatibility. The same applies to the
+parse produced when this option is asserted.
+
+The default is false.
+
 =item significant boolean
 
 If true, this option causes only significant elements to be dumped.
@@ -184,6 +196,7 @@ ignored.
 	    lister => undef,
 	    object => undef,
 	    source => $re,
+	    strict => $args{strict},
 	};
 
 	foreach my $key ( qw{ default_modifiers parse postderef } ) {
@@ -305,7 +318,7 @@ sub _safe_version {
     return defined $version ? "'$version'" : 'undef';
 }
 
-sub _nav {
+sub __nav {
     my ( $self, @args ) = @_;
     my $rslt = $self->_safe( @args );
     $rslt =~ s/ ' (\w+) ' , /$1 =>/smxg;
@@ -317,11 +330,7 @@ sub _nav {
 sub _perl_version {
     my ( undef, $elem ) = @_;		# Invocant unused
 
-    my $rslt = $elem->perl_version_introduced() . ' <= $]';
-    if ( my $max = $elem->perl_version_removed() ) {
-	$rslt .= ' < ' . $max;
-    }
-    return $rslt;
+    return $elem->requirements_for_perl();
 }
 
 sub _content {
@@ -356,7 +365,7 @@ sub _tokens_dump {
 sub _format_default_modifiers {
     my ( $self, $subr, $elem ) = @_;
     my @arg = $self->_safe( $elem );
-    foreach my $attr ( qw{ default_modifiers parse postderef } ) {
+    foreach my $attr ( qw{ default_modifiers parse postderef strict } ) {
 	defined ( my $val = $self->{$attr} )
 	    or next;
 	'ARRAY' eq ref $val
@@ -455,11 +464,17 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__dump {
 	    ? sprintf "\tfailures=%d\tmax_capture_number=%d",
 		$self->failures(), $self->max_capture_number()
 	    : sprintf "\tfailures=%d", $self->failures();
+
     $dumper->{perl_version}
 	and $rslt[-1] .= "\t" . $dumper->_perl_version( $self );
-    $dumper->{explain}
-	and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
-	    $dumper, pop @rslt );
+
+    if ( defined ( my $err = $self->error() ) ) {
+	$rslt[-1] .= "\t$err";
+    } else {
+	$dumper->{explain}
+	    and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
+		$dumper, pop @rslt );
+    }
 
     my $indent = ' ' x $dumper->{indent};
     foreach my $elem ( $self->children() ) {
@@ -475,10 +490,18 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
 
     my @rslt;
     @rslt = (
-	'choose  ( ' . $dumper->_nav( $self->nav() ) . ' );',
+	'choose  ( ' . $dumper->__nav( $self->nav() ) . ' );',
 	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'count   ( ' . scalar $self->children() . ' );',
     );
+
+    if ( defined( my $err = $self->error() ) ) {
+
+	push @rslt,
+	    'error   ( ' . $dumper->_safe( $err ) . ' );';
+
+    }
+
     if ( $dumper->{perl_version} ) {
 	foreach my $method ( qw{
 	    perl_version_introduced
@@ -549,12 +572,14 @@ sub _format_value {
 		push @rslt, $err;
 	    }
 	}
+
 	@rslt = ( join "\t", @rslt );
+
 	$dumper->{explain}
+	    and not defined $self->error()
 	    and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
 		$dumper, pop @rslt );
 
-	@rslt = ( join( "\t", @rslt ) );
 	my $indent = ' ' x $dumper->{indent};
 	foreach my $elem ( $self->children() ) {
 	    push @rslt, map { $indent . $_ }
@@ -572,7 +597,7 @@ sub PPIx::Regexp::Structure::__PPIX_DUMPER__test {
 
     my @nav = $self->nav();
     my @rslt = (
-	'choose  ( ' . $dumper->_nav( @nav ) . ' );',
+	'choose  ( ' . $dumper->__nav( @nav ) . ' );',
 	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'count   ( ' . scalar $self->children() . ' );',
     );
@@ -585,12 +610,12 @@ sub PPIx::Regexp::Structure::__PPIX_DUMPER__test {
     }
     foreach my $method ( qw{ start type finish } ) {
 	my @eles = $self->$method();
-	push @rslt, 'choose  ( ' . $dumper->_nav(
+	push @rslt, 'choose  ( ' . $dumper->__nav(
 	    @nav, $method, [] ) . ' );',
 	    'count   ( ' . scalar @eles . ' );';
 	foreach my $inx ( 0 .. $#eles ) {
 	    my $elem = $eles[$inx];
-	    push @rslt, 'choose  ( ' . $dumper->_nav(
+	    push @rslt, 'choose  ( ' . $dumper->__nav(
 		@nav, $method, $inx ) . ' );',
 		'class   ( ' . $dumper->_safe( ref $elem || $elem ) . ' );',
 		'content ( ' . $dumper->_safe( $elem ) . ' );';
@@ -624,15 +649,15 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__dump {
 
     my @rslt = ( ref $self, $dumper->_safe( $self ) );
 
+    $dumper->{perl_version}
+	and push @rslt, $dumper->_perl_version( $self );
+
     if ( defined( my $err = $self->error() ) ) {
 
 	return join "\t", @rslt, $err;
 
     } else {
 
-	$dumper->{perl_version}
-	    and push @rslt, $dumper->_perl_version( $self );
-
 	if ( $dumper->{ordinal} && $self->can( 'ordinal' )
 	    && defined ( my $ord = $self->ordinal() ) ) {
 	    push @rslt, sprintf '0x%02x', $ord;
@@ -671,6 +696,7 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__dump {
 	$dumper->{explain}
 	    and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
 		$dumper, pop @rslt );
+
 	return @rslt;
     }
 }
@@ -682,7 +708,7 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__test {
 
     @nav or @nav = $self->nav();
     my @rslt = (
-	'choose  ( ' . join(', ', $dumper->_nav( @nav ) ) . ' );',
+	'choose  ( ' . join(', ', $dumper->__nav( @nav ) ) . ' );',
 	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'content ( ' . $dumper->_safe( $self ) . ' );',
     );
@@ -740,7 +766,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
