@@ -38,13 +38,15 @@ use base qw{ PPIx::Regexp::Element };
 
 use Carp;
 use List::Util qw{ max };
-use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{ FALSE MINIMUM_PERL NODE_UNKNOWN TRUE };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.047';
+our $VERSION = '0.055';
 
-sub _new {
+use constant ELEMENT_UNKNOWN	=> NODE_UNKNOWN;
+
+sub __new {
     my ( $class, @children ) = @_;
     ref $class and $class = ref $class;
     foreach my $elem ( @children ) {
@@ -60,6 +62,26 @@ sub _new {
     return $self;
 }
 
+sub accepts_perl {
+    my ( $self, $version ) = @_;
+    foreach my $elem ( $self->elements() ) {
+	$elem->accepts_perl( $version )
+	    or return FALSE;
+    }
+    return TRUE;
+}
+
+# NOTE: this method is to be used ONLY for requirements_for_perl(). See
+# PPIx::Regexp::Element for exposure plans. IF it is exposed, that is
+# where it will be documented.
+sub __structured_requirements_for_perl {
+    my ( $self, $rslt ) = @_;
+    foreach my $elem ( $self->elements() ) {
+	$elem->__structured_requirements_for_perl( $rslt );
+    }
+    return $rslt;
+}
+
 =head2 child
 
  my $kid = $node->child( 0 );
@@ -200,9 +222,9 @@ This convenience method takes the same arguments as C<find>, but instead
 of the found objects themselves returns their parents. No parent will
 appear more than once in the output.
 
-The return is a reference to the array of parents if any were found. If
-none were found the return is false but defined. If an error occurred
-the return is C<undef>.
+This method returns a reference to the array of parents if any were
+found. If no parents were found the return is false but defined. If an
+error occurred the return is C<undef>.
 
 =cut
 
@@ -289,7 +311,8 @@ supported by this package.
 
 sub perl_version_introduced {
     my ( $self ) = @_;
-    return max( MINIMUM_PERL,
+    return max( grep { defined $_ } MINIMUM_PERL,
+	$self->{perl_version_introduced},
 	map { $_->perl_version_introduced() } $self->elements() );
 }
 
@@ -383,6 +406,20 @@ sub schildren {
     }
 }
 
+sub scontent {
+    my ( $self ) = @_;
+    # As of the invention of this method all nodes are significant, so
+    # the following statement is pure paranoia on my part. -- TRW
+    $self->significant()
+	or return;
+    # This needs to be elements(), not children() or schildren() -- or
+    # selements() if that is ever invented. Not children() or
+    # schildren() because those ignore the delimiters. Not selements()
+    # (if that ever comes to pass) because scontent() has to make the
+    # significance check, so selements() would be wasted effort.
+    return join( '', map{ $_->scontent() } $self->elements() );
+}
+
 sub tokens {
     my ( $self ) = @_;
     return ( map { $_->tokens() } $self->elements() );
@@ -394,7 +431,7 @@ sub unescaped_content {
 }
 
 # Help for nav();
-sub _nav {
+sub __nav {
     my ( $self, $child ) = @_;
     refaddr( $child->parent() ) == refaddr( $self )
 	or return;
@@ -405,20 +442,26 @@ sub _nav {
 }
 
 sub __error {
-    my ( $self ) = @_;	# second argument unused
-    confess 'Programming error - __error() must be overridden',
-	' for class ', ref $self;
+    my ( $self, $msg, %arg ) = @_;
+    defined $msg
+	or $msg = 'Was class ' . ref $self;
+    $self->{error} = $msg;
+    bless $self, $self->ELEMENT_UNKNOWN();
+    foreach my $key ( keys %arg ) {
+	$self->{$key} = $arg{$key};
+    }
+    return 1;
 }
 
 
 # Called by the lexer once it has done its worst to all the tokens.
-# Called as a method with no arguments. The return is the number of
-# parse failures discovered when finalizing.
+# Called as a method with the lexer as argument. The return is the
+# number of parse failures discovered when finalizing.
 sub __PPIX_LEXER__finalize {
-    my ( $self ) = @_;
+    my ( $self, $lexer ) = @_;
     my $rslt = 0;
     foreach my $elem ( $self->elements() ) {
-	$rslt += $elem->__PPIX_LEXER__finalize();
+	$rslt += $elem->__PPIX_LEXER__finalize( $lexer );
     }
     return $rslt;
 }
@@ -447,7 +490,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
