@@ -12,7 +12,7 @@ use PPIx::Regexp::Constant qw{
     TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.050';
+our $VERSION = '0.055';
 
 {
     # Names of classes containing tokenization machinery. There are few
@@ -237,7 +237,8 @@ C<PPIx::Regexp::StringTokenizer> has no descendants.
 
 =head1 DESCRIPTION
 
-This class provides tokenization of string literals.
+This class provides tokenization of string literals. It is deprecated in
+favor of the use of L<PPIx::QuoteLike|PPIx::QuoteLike>.
 
 =head1 METHODS
 
@@ -259,7 +260,7 @@ Tom Wyant F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015-2016 by Thomas R. Wyant, III
+Copyright (C) 2015-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
