@@ -5,7 +5,15 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-our $VERSION = '0.050';
+use PPIx::Regexp::Constant qw{
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_2
+};
+
+our $VERSION = '0.055';
+
+sub __following_literal_left_curly_disallowed_in {
+    return LITERAL_LEFT_CURLY_REMOVED_PHASE_2;
+}
 
 1;
 
@@ -74,7 +82,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2016 by Thomas R. Wyant, III
+Copyright (C) 2013-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
