@@ -34,10 +34,10 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-our $VERSION = '0.047';
+our $VERSION = '0.055';
 
 sub __PPIX_LEXER__finalize {
-    my ( $self ) = @_;
+    my ( $self, $lexer ) = @_;
 
     # Assume no errors.
     my $rslt = 0;
@@ -79,7 +79,7 @@ sub __PPIX_LEXER__finalize {
 
     # Delegate to the superclass to finalize our children, now that we
     # have finished messing with them.
-    $rslt += $self->SUPER::__PPIX_LEXER__finalize();
+    $rslt += $self->SUPER::__PPIX_LEXER__finalize( $lexer );
 
     return $rslt;
 }
@@ -99,7 +99,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
