@@ -23,13 +23,13 @@ L<PPIx::Regexp::Token::Greediness|PPIx::Regexp::Token::Greediness>,
 L<PPIx::Regexp::Token::GroupType|PPIx::Regexp::Token::GroupType>,
 L<PPIx::Regexp::Token::Literal|PPIx::Regexp::Token::Literal>,
 L<PPIx::Regexp::Token::Modifier|PPIx::Regexp::Token::Modifier>,
+L<PPIx::Regexp::Token::NoOp|PPIx::Regexp::Token::NoOp>,
 L<PPIx::Regexp::Token::Operator|PPIx::Regexp::Token::Operator>,
 L<PPIx::Regexp::Token::Quantifier|PPIx::Regexp::Token::Quantifier>,
 L<PPIx::Regexp::Token::Reference|PPIx::Regexp::Token::Reference>,
 L<PPIx::Regexp::Token::Structure|PPIx::Regexp::Token::Structure>,
-L<PPIx::Regexp::Token::Unknown|PPIx::Regexp::Token::Unknown>,
-L<PPIx::Regexp::Token::Unmatched|PPIx::Regexp::Token::Unmatched> and
-L<PPIx::Regexp::Token::Whitespace|PPIx::Regexp::Token::Whitespace>.
+L<PPIx::Regexp::Token::Unknown|PPIx::Regexp::Token::Unknown> and
+L<PPIx::Regexp::Token::Unmatched|PPIx::Regexp::Token::Unmatched>.
 
 =head1 DESCRIPTION
 
@@ -53,7 +53,7 @@ use base qw{PPIx::Regexp::Element};
 use Carp qw{ confess };
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.047';
+our $VERSION = '0.055';
 
 use constant TOKENIZER_ARGUMENT_REQUIRED => 0;
 
@@ -68,7 +68,7 @@ sub __new {
 	content => $content,
     };
 
-    foreach my $key ( qw{ perl_version_introduced } ) {
+    foreach my $key ( qw{ perl_version_introduced perl_version_removed } ) {
 	defined $arg{$key}
 	    and $self->{$key} = $arg{$key};
     }
@@ -85,8 +85,13 @@ sub content {
 sub perl_version_introduced {
     my ( $self ) = @_;
     return defined $self->{perl_version_introduced} ?
-    $self->{perl_version_introduced} :
-    MINIMUM_PERL;
+	$self->{perl_version_introduced} :
+	MINIMUM_PERL;
+}
+
+sub perl_version_removed {
+    my ( $self ) = @_;
+    return $self->{perl_version_removed};
 }
 
 sub unescaped_content {
@@ -96,9 +101,16 @@ sub unescaped_content {
     return $content;
 }
 
+sub scontent {
+    my ( $self ) = @_;
+    $self->significant()
+	and return $self->{content};
+    return;
+}
+
 # Called by the lexer once it has done its worst to all the tokens.
-# Called as a method with no arguments. The return is the number of
-# parse failures discovered when finalizing.
+# Called as a method with the lexer as argument. The return is the
+# number of parse failures discovered when finalizing.
 sub __PPIX_LEXER__finalize {
     return 0;
 }
@@ -118,7 +130,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
