@@ -47,10 +47,12 @@ use warnings;
 use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{
-    COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
+    COOKIE_CLASS
+    LITERAL_LEFT_CURLY_ALLOWED
+    MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.050';
+our $VERSION = '0.055';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -117,6 +119,12 @@ sub perl_version_introduced {
     }
 }
 
+# An un-escaped literal left curly bracket can always follow this
+# element.
+sub __following_literal_left_curly_disallowed_in {
+    return LITERAL_LEFT_CURLY_ALLOWED;
+}
+
 # By logic we should handle '$' here. But
 # PPIx::Regexp::Token::Interpolation needs to process it to see if it is
 # a sigil. If it is not, that module is expected to make it into an
@@ -180,7 +188,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
