@@ -36,10 +36,13 @@ use warnings;
 use base qw{ PPIx::Regexp::Token::CharClass };
 
 use PPIx::Regexp::Constant qw{
-    COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
+    COOKIE_CLASS
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_1
+    LITERAL_LEFT_CURLY_REMOVED_PHASE_2
+    MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.047';
+our $VERSION = '0.055';
 
 {
 
@@ -72,10 +75,15 @@ our $VERSION = '0.047';
 
     sub explain {
 	my ( $self ) = @_;
-	if ( $self->content() =~ m/ \A \\ ( [Pp] ) [{] ( .* ) [}] \z /smx ) {
+	if ( $self->content() =~ m/ \A \\ ( [Pp] ) ( [{] .* [}] | . ) \z /smx ) {
+	    my ( $kind, $prop ) = ( $1, $2 );
+	    if ( 1 < length $prop ) {
+		$prop =~ s/ \A [{] //smx;
+		$prop =~ s/ [}] \z //smx;
+	    }
 	    return sprintf
 		q<Match character %s Unicode or custom property '%s'>,
-		$kind_of_match{$1}, $2;
+		$kind_of_match{$kind}, $prop;
 	}
 	return $self->SUPER::explain();
     }
@@ -104,38 +112,38 @@ our $VERSION = '0.047';
 ##    return ( $self->{is_case_sensitive} = $self->_is_case_sensitive() );
 ##}
 
-{
-    my %case_sensitive = map { $_ => 1 } qw{
-        generalcategory=lowercaseletter generalcategory=ll
-	    gc=lowercaseletter gc=ll
-        generalcategory=titlecaseletter generalcategory=lt
-	    gc=titlecaseletter gc=lt
-        generalcategory=uppercaseletter generalcategory=lu
-	    gc=uppercaseletter gc=lu
-	lowercaseletter lowercase lower ll
-	titlecaseletter titlecase title lt
-	uppercaseletter uppercase upper lu
-	lowercase=y lower=y lowercase=n lower=n
-	titlecase=y title=y titlecase=n title=n
-	uppercase=y upper=y uppercase=n upper=n
-    };
-
-    sub _is_case_sensitive {
-	my ( $self ) = @_;
-	my $content = $self->content();
-	$content =~ m/ \A \\ p [{] ( .* ) [}] /smxi
-	    or return 0;
-	$content = lc $1;
-	$content =~ s/ \A ^ //smx;
-	$content =~ s/ [\s_-] //smxg;
-	$content =~ s/ \A is //smx;
-	$content =~ s/ : /=/smxg;
-	$content =~ s/ = (?: yes | t | true ) \b /=y/smxg;
-	$content =~ s/ = (?: no | f | false ) \b /=n/smxg;
-	return $case_sensitive{$content} || 0;
-    }
-
-}
+##{
+##    my %case_sensitive = map { $_ => 1 } qw{
+##        generalcategory=lowercaseletter generalcategory=ll
+##	    gc=lowercaseletter gc=ll
+##        generalcategory=titlecaseletter generalcategory=lt
+##	    gc=titlecaseletter gc=lt
+##        generalcategory=uppercaseletter generalcategory=lu
+##	    gc=uppercaseletter gc=lu
+##	lowercaseletter lowercase lower ll
+##	titlecaseletter titlecase title lt
+##	uppercaseletter uppercase upper lu
+##	lowercase=y lower=y lowercase=n lower=n
+##	titlecase=y title=y titlecase=n title=n
+##	uppercase=y upper=y uppercase=n upper=n
+##    };
+##
+##    sub _is_case_sensitive {
+##	my ( $self ) = @_;
+##	my $content = $self->content();
+##	$content =~ m/ \A \\ p [{] ( .* ) [}] /smxi
+##	    or return 0;
+##	$content = lc $1;
+##	$content =~ s/ \A ^ //smx;
+##	$content =~ s/ [\s_-] //smxg;
+##	$content =~ s/ \A is //smx;
+##	$content =~ s/ : /=/smxg;
+##	$content =~ s/ = (?: yes | t | true ) \b /=y/smxg;
+##	$content =~ s/ = (?: no | f | false ) \b /=n/smxg;
+##	return $case_sensitive{$content} || 0;
+##    }
+##
+##}
 
 {
 
@@ -180,6 +188,24 @@ our $VERSION = '0.047';
     }
 }
 
+# This is one of the larger complications of
+# https://rt.perl.org/Public/Bug/Display.html?id=128213
+# where it transpired that un-escaped literal left curlies were not
+# giving warnings/errors in /.{/, /\p{...}{/, and /\P{...}{/, but were
+# for all the others that bin into this class (e.g. /\s{/).
+# Note that the perldelta for 5.25.1 and 5.26.0 do not acknowledge tha
+# phased deprecation, and pretend that everything was done on the phase
+# 1 schedule. This appears to be deliberate per
+# https://rt.perl.org/Ticket/Display.html?id=131352
+sub __following_literal_left_curly_disallowed_in {
+    my ( $self ) = @_;
+    q<.> eq ( my $content = $self->content() )
+	and return LITERAL_LEFT_CURLY_REMOVED_PHASE_2;
+    $content =~ m/ \A \\ p \{ /smxi
+	and return LITERAL_LEFT_CURLY_REMOVED_PHASE_2;
+    return LITERAL_LEFT_CURLY_REMOVED_PHASE_1;
+}
+
 sub __PPIX_TOKENIZER__regexp {
     my ( undef, $tokenizer, $character ) = @_;
 
@@ -194,7 +220,8 @@ sub __PPIX_TOKENIZER__regexp {
     if ( my $accept = $tokenizer->find_regexp(
 	    qr{ \A \\ (?:
 		[wWsSdDvVhHXRNC] |
-		[Pp] \{ \s* \^? [\w:=\s-]+ \}
+		[Pp] \{ \s* \^? [\w:=\s-]+ \} |
+		[Pp] [CLMNPSZ]	# perluniprops for 5.26.1
 	    ) }smx
 	) ) {
 	if ( $in_class ) {
@@ -231,7 +258,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
