@@ -28,6 +28,7 @@ use PPIx::Regexp::Token::GroupType::BranchReset	();
 use PPIx::Regexp::Token::GroupType::Code	();
 use PPIx::Regexp::Token::GroupType::Modifier	();
 use PPIx::Regexp::Token::GroupType::NamedCapture	();
+use PPIx::Regexp::Token::GroupType::Script_Run	();
 use PPIx::Regexp::Token::GroupType::Subexpression	();
 use PPIx::Regexp::Token::GroupType::Switch	();
 use PPIx::Regexp::Token::Interpolation		();
@@ -42,7 +43,7 @@ use PPIx::Regexp::Token::Whitespace		();
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.050';
+our $VERSION = '0.055';
 
 our $DEFAULT_POSTDEREF;
 defined $DEFAULT_POSTDEREF
@@ -738,7 +739,7 @@ sub tokens {
 	attribute => {
 	},
 	method => {
-	    prior	=> 0,
+	    prior	=> 3,
 	},
     );
 
@@ -1574,13 +1575,12 @@ returns it.
     and print "The prior token can be quantified.\n";
 
 This method is deprecated in favor of
-L<prior_significant_tokrn()|/prior_significant_token>. Six months after
-the release of version 0.044_01 it will start warning on the
-first use. Six months after that it will warn on every use. Six months
-after that a fatal exception will be thrown when it is called. I am not
-sure I need to put this though a deprecation cycle, given that this
-method is documented as not being part of the public interface, but I
-choose to err on the side of caution.
+L<prior_significant_tokrn()|/prior_significant_token>. As of version [%%
+next_version %%] it is a fatal error to call it. Six months after the
+release of this version it will be removed.  I am not sure I need to put
+this though a deprecation cycle, given that this method is documented as
+not being part of the public interface, but I choose to err on the side
+of caution.
 
 This method calls the named method on the most-recently-instantiated
 significant token, and returns the result. Any arguments subsequent to
@@ -1636,7 +1636,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2016 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
